@@ -3,6 +3,8 @@ use warnings;
 use strict;
 use base qw(App::gh::Command);
 use App::gh::Utils;
+use LWP::Simple qw(get);
+use JSON;
 
 
 sub parse_remote_param {
